@@ -1,8 +1,8 @@
-smacofDeleteOne <- function (delta, ndim, metric = FALSE) {
+smacofDeleteOne <- function (delta, ndim, type) {
     n <- nrow (delta)
     x <- array (0, c (n, ndim, n))
     for (i in 1:n) {
-        xi <- smacofSym(delta[-i, -i], ndim = ndim, metric = metric)$conf
+        xi <- smacofSym(delta[-i, -i], ndim = ndim, type = type)$conf
         x[((1 : n)[-i]), (1 : ndim), i] <- xi
         x[i, (1 : ndim), i] <- 0
         }
